;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "klere-theme" "20250517.452"
  "A dark theme with lambent color highlights and incremental grays."
  '((emacs "24"))
  :url "https://github.com/tomenzgg/emacs-klere-theme"
  :commit "377cc33617184e23acde6707beaf8938915fe093"
  :revdesc "377cc3361718"
  :authors '(("Jean Libète" . "tomenzgg@mail.mayfirst.org"))
  :maintainers '(("Jean Libète" . "tomenzgg@mail.mayfirst.org")))
